/*
	Software License Agreement (BSD License) 
	Copyright (c) 2010, Servoy Stuff
	All rights reserved.

	Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following 
	conditions are met:

	Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
	Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
	in the documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
	NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
	THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
	OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.jfree.eastwood;

import java.awt.Graphics2D;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;

import org.jfree.chart.plot.PlotRenderingInfo;
import org.jfree.chart.plot.PlotState;
import org.jfree.chart.plot.dial.DialPlot;
import org.jfree.data.general.ValueDataset;

/**
 * @author Servoy Stuff
 * http://www.servoy-stuff.net/
 */
public class ExtendedDialPlot extends DialPlot {

	private static final long serialVersionUID = 1L;
	
	private boolean proportional;
	
	public ExtendedDialPlot() {
		super();
	}
	
	public ExtendedDialPlot(ValueDataset dataset) {
		super(dataset);
	}


    public void draw(Graphics2D g2, Rectangle2D area, Point2D anchor,
            PlotState parentState, PlotRenderingInfo info) {
    	
    	Rectangle2D frame = viewToFrame(area);
    	super.draw(g2, frame, anchor, parentState, info);
    }
    
    public void setProportional(boolean proportional) {
		this.proportional = proportional;
	}

	private Rectangle2D viewToFrame(Rectangle2D view) {
    	if (proportional) {
	        double width = view.getWidth() / getViewWidth();
	        double height = view.getHeight() / getViewHeight();
	        double minMax = Math.min(width, height);
	        width = minMax;
	        height = minMax;
	        double x = view.getX() + ((view.getWidth()/2) - (width/2));
	        double y = view.getY() - (height * getViewY());
	        return new Rectangle2D.Double(x, y, width, height);
    	} else {
    		return view;
    	}
    }
}
