/*
	Software License Agreement (BSD License) 
	Copyright (c) 2010, Servoy Stuff
	All rights reserved.

	Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following 
	conditions are met:

	Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
	Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer 
	in the documentation and/or other materials provided with the distribution.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
	NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
	THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
	OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.jfree.eastwood;

import java.awt.Shape;
import java.awt.geom.Ellipse2D;
import java.awt.geom.Rectangle2D;

import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.data.xy.XYDataItem;
import org.jfree.data.xy.XYSeries;

/**
 *
 * @author Servoy Stuff
 * http://www.servoy-stuff.net/
 *
 */
public class ScatterShapeRenderer extends XYLineAndShapeRenderer {

	private static final long serialVersionUID = 1L;
	private static final double GOOGLE_MULTIPLIER = 1.0 + (2.0/3.0);
	private XYSeries pointSizes;
	
	public ScatterShapeRenderer() {
		super();
	}

	public ScatterShapeRenderer(boolean lines, boolean shapes) {
		super(lines, shapes);
	}

	/* (non-Javadoc)
	 * @see org.jfree.chart.renderer.AbstractRenderer#getItemShape(int, int)
	 */
	public Shape getItemShape(int row, int column) {
		Shape shape = super.getItemShape(row, column);
		if (pointSizes == null) return shape;
		XYDataItem di =  (column < pointSizes.getItemCount()) ? pointSizes.getDataItem(column) : null;
		if (di != null) {
			Number size = di.getY();
			if (size != null) {
				Rectangle2D r = shape.getBounds2D();
				double width = r.getWidth();
				double height = r.getHeight();
				return new Ellipse2D.Double(
					r.getX(),
					r.getY(),
					(width*size.doubleValue())*GOOGLE_MULTIPLIER,
					(height*size.doubleValue())*GOOGLE_MULTIPLIER
				);
			}
		}
		return shape;
	}


	public void setPointSizes(XYSeries pointSizes) {
		this.pointSizes = pointSizes;
	}

}
